==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/sl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Upravljanje Lightbox Gallary parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "upravljanje Galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Cele Širina slike");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Višina");
define('MANAGE_GALLERY_THUMB_WIDTH', "Sličica Širina");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Višina slike");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ohrani Thumb razmerja stranic");
define('MANAGE_GALLERY_SHOW_TITLES', "prikaži naslovov");
define('MANAGE_GALLERY_DISABLE_SORT', "Onemogoči Razvrsti");
define('MANAGE_GALLERY_DELETE_IMAGE', "Izbriši sliko");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Prihranite Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite &#39;Update&#39; to objavo <br /> preneseni slike.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Vse slike so spremenjena in nastavitve so shranjene.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Prišlo je spreminjanje velikosti slike ali shranjevanju nastavitev je prišlo do napake.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Vaša slika (s) je bila naložena.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Pri nalaganju sliko (e) je prišlo do napake.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Datoteka, ki jo poskušate naložiti, ni slike.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Datoteka, ki jo poskušate naložiti, je prevelika.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Naslov je bil shranjen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ali ste prepričani, da želite izbrisati sliko");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Slika je bila izbrisana.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Pri brisanju slike je prišlo do napake.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Shranjevanje parametrov in spreminjanje velikosti slike, prosimo počakajte ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nalaganje, počakajte ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Vrstni red razvrščanja ni bil shranjen. Ali želite shraniti vrstni red?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Da slika vrsta je bila shranjena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Pri shranjevanju neke slike napake.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/sl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Upravljanje Lightbox Gallary parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "upravljanje Galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Cele Širina slike");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Višina");
define('MANAGE_GALLERY_THUMB_WIDTH', "Sličica Širina");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Višina slike");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ohrani Thumb razmerja stranic");
define('MANAGE_GALLERY_SHOW_TITLES', "prikaži naslovov");
define('MANAGE_GALLERY_DISABLE_SORT', "Onemogoči Razvrsti");
define('MANAGE_GALLERY_DELETE_IMAGE', "Izbriši sliko");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Prihranite Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite &#39;Update&#39; to objavo <br /> preneseni slike.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Vse slike so spremenjena in nastavitve so shranjene.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Prišlo je spreminjanje velikosti slike ali shranjevanju nastavitev je prišlo do napake.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Vaša slika (s) je bila naložena.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Pri nalaganju sliko (e) je prišlo do napake.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Datoteka, ki jo poskušate naložiti, ni slike.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Datoteka, ki jo poskušate naložiti, je prevelika.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Naslov je bil shranjen.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ali ste prepričani, da želite izbrisati sliko");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Slika je bila izbrisana.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Pri brisanju slike je prišlo do napake.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Shranjevanje parametrov in spreminjanje velikosti slike, prosimo počakajte ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Nalaganje, počakajte ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Vrstni red razvrščanja ni bil shranjen. Ali želite shraniti vrstni red?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Da slika vrsta je bila shranjena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Pri shranjevanju neke slike napake.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Datoteka, ki jo poskušate naložiti, je večja od nastavitev PHP »upload_max_filesize« ali »post_max_size«. Če želite povečati te omejitve, se obrnite na skrbnika sistema.");
?>
